<!DOCTYPE html>
<html lang="en">
    <head>
        <title>{{ title }}</title>
        <meta name="viewport" content="width=device-width"/>
        {{ resources }}
    </head>
    <body>

        <div id="{{ html_id }}" style="display:inline-block;width:100%;">
            <survey :survey='survey' />
        </div>

        <script type="text/javascript">
            {{ survey_js }}
        </script>

    </body>
</html>

