<!DOCTYPE html>
<html lang="en">
    <head>
        <title>{{ title }}</title>
        <meta name="viewport" content="width=device-width"/>
	{{ resources }}
    </head>
    <body>

	<ng-app id="{{ html_id {}"><ng-app>

	<script type="text/javascript">
	    {{ survey_js }}
	</script>

    </body>
</html>
